Crate maudit_rolldown_common

Re-exports

pub use bundler_options::*;

Modules

bundler_options
This module is to help rolldown crate could export types related bundler options easily. rolldown crate could use pub use rolldown_common::bundler_options::*; to export all types, so we don’t need write the same code in rolldown crate again.
dynamic_import_usage
side_effects

Structs

AddEntryModuleMsg
Asset
Assets is final output of the bundling process. Inputs -> Modules -> Chunks -> Assets
AssetIdx
AssetView
AstScopeIdx
AstScopes
BundleEndEventData
Cache
Chunk
ChunkIdx
ChunkTable
CrossChunkImportItem
CssAssetNameReplacer
CssRenderer
CssView
DebugStmtInfoForTreeShaking
EcmaAssetMeta
EcmaAstIdx
EcmaModuleAstUsage
EcmaRelated
EcmaView
EcmaViewMeta
EmittedAsset
EmittedChunk
EmittedChunkInfo
EntryPoint
ExternalModule
ExternalModuleIdx
FileEmitter
ImportMetaRolldownAssetReplacer
ImportRecordIdx
ImportRecordMeta
ImporterRecord
InstantiatedChunk
InstantiatedChunks are derived from Chunks. Different InstantiatedChunks can be derived from the same Chunk by different Generators.
LocalExport
This is a representation for statements like
MemberExprRef
For member expression, e.g. foo_ns.bar_ns.c
ModuleId
ModuleId is the unique string identifier for each module.
ModuleIdx
ModuleInfo
ModuleRenderOutput
ModuleTable
Modules
NamedImport
This is a representation for statements like
NamespaceAlias
NormalModule
NormalModuleTaskResult
OutputAsset
OutputChunk
OutputsDiagnostics
PackageJson
PreliminaryFilename
Represents a filename that might contains hash placeholder.
RenderedModule
ResolvedExport
ResolvedId
RollupPreRenderedAsset
RollupPreRenderedChunk
RollupRenderedChunk
RuntimeModuleBrief
RuntimeModuleTaskResult
StmtInfo
StmtInfoIdx
StmtInfoMeta
StmtInfos
SymbolNameRefToken
A token that represents a symbol name in a module.
SymbolRef
SymbolRef is used to represent a symbol in a module when there are multiple modules.
SymbolRefDb
SymbolRefDbForModule
SymbolRefFlags
WatcherChangeData

Enums

BundleEvent
ChunkKind
EntryPointKind
ExportsKind
ImportKind
InstantiationKind
Interop
LegacyModuleIdx
Module
ModuleDefFormat
Module Definition Format.
ModuleLoaderMsg
ModuleRenderArgs
ModuleView
Output
Specifier
StrOrBytes
SymbolOrMemberExprRef
ThisExprReplaceKind
WatcherChangeKind
WatcherEvent
WrapKind

Constants

DUMMY_MODULE_IDX

Statics

ROLLDOWN_IGNORE
RUNTIME_MODULE_ID

Traits

BundlerFileSystem
You don’t need impl this trait manually, it’s already implemented for all types that implement FileSystem + Default + Clone + 'static.
GetLocalDb
SourceMutation

Functions

common_debug_symbol_ref
passing a SymbolRef, it will return it’s string repr, the format: ${stable_id} -> ${symbol_name}
generate_replace_this_expr_map
get_leading_comment
Get the leading comment of a node when condition is satisfy
is_existing_node_builtin_modules
Using phf should be faster, but it would increase the compile time, since this function is not frequently used, we use binary_search instead.

Type Aliases

IndexExternalModules
IndexModules
RawImportRecord
ResolvedImportRecord
SharedFileEmitter