pub struct SymbolRefDbForModule {
pub flags: FxHashMap<SymbolId, SymbolRefFlags>,
pub classic_data: IndexVec<SymbolId, SymbolRefDataClassic>,
/* private fields */
}Fields
flags: FxHashMap<SymbolId, SymbolRefFlags>classic_data: IndexVec<SymbolId, SymbolRefDataClassic>Implementations
Sourceimpl SymbolRefDbForModule
impl SymbolRefDbForModule
pub fn new( symbol_table: SymbolTable, owner_idx: ModuleIdx, top_level_scope_id: ScopeId, ) -> Self
pub fn create_facade_root_symbol_ref(&mut self, name: &str) -> SymbolRef
Sourcepub fn create_symbol(&mut self)
👎Deprecated: Use create_facade_root_symbol_ref instead
pub fn create_symbol(&mut self)
create_facade_root_symbol_ref insteadThis method is used to hide the SymbolTable::create_symbol method since
SymbolRefDbForModule impl Deref for SymbolTable.
Methods from Deref<Target = SymbolTable>
pub fn names(&self) -> impl Iterator<Item = &str>
pub fn resolved_references(&self) -> impl Iterator<Item = &Vec<'_, ReferenceId>>
Sourcepub fn symbol_ids(&self) -> impl Iterator<Item = SymbolId>
pub fn symbol_ids(&self) -> impl Iterator<Item = SymbolId>
Iterate over all symbol IDs in this table.
Use ScopeTree::iter_bindings_in to only iterate over symbols declared in a specific
scope.
Example
use oxc_semantic::Semantic;
let semantic: Semantic<'_> = parse_and_analyze("./foo.js");
let classes = semantic
.scopes()
.symbol_ids()
.filter(|&symbol_id| {
let flags = semantic.symbols().get_flags(symbol_id);
flags.is_class()
})
.collect::<Vec<_>>();Sourcepub fn get_name(&self, symbol_id: SymbolId) -> &str
pub fn get_name(&self, symbol_id: SymbolId) -> &str
Get the identifier name a symbol is bound to.
Sourcepub fn set_name(&mut self, symbol_id: SymbolId, name: &str) -> &str
pub fn set_name(&mut self, symbol_id: SymbolId, name: &str) -> &str
Rename a symbol.
Returns the old name.
Sourcepub fn get_flags(&self, symbol_id: SymbolId) -> SymbolFlags
pub fn get_flags(&self, symbol_id: SymbolId) -> SymbolFlags
Get the SymbolFlags for a symbol, which describe how the symbol is declared.
To find how a symbol is used, use SymbolTable::get_resolved_references.
Sourcepub fn get_flags_mut(&mut self, symbol_id: SymbolId) -> &mut SymbolFlags
pub fn get_flags_mut(&mut self, symbol_id: SymbolId) -> &mut SymbolFlags
Get a mutable reference to a symbol’s flags.
pub fn get_redeclarations(&self, symbol_id: SymbolId) -> &[Span]
pub fn union_flag(&mut self, symbol_id: SymbolId, includes: SymbolFlags)
pub fn set_scope_id(&mut self, symbol_id: SymbolId, scope_id: ScopeId)
pub fn get_scope_id(&self, symbol_id: SymbolId) -> ScopeId
Sourcepub fn get_declaration(&self, symbol_id: SymbolId) -> NodeId
pub fn get_declaration(&self, symbol_id: SymbolId) -> NodeId
Get the ID of the AST node declaring a symbol.
This node will be a VariableDeclaration, Function, or some other AST node
that has a BindingIdentifier or a BindingPattern. It will not point to the
binding pattern or identifier node itself.
pub fn create_symbol( &mut self, span: Span, name: &str, flags: SymbolFlags, scope_id: ScopeId, node_id: NodeId, ) -> SymbolId
pub fn add_redeclaration(&mut self, symbol_id: SymbolId, span: Span)
pub fn create_reference(&mut self, reference: Reference) -> ReferenceId
Sourcepub fn get_reference(&self, reference_id: ReferenceId) -> &Reference
pub fn get_reference(&self, reference_id: ReferenceId) -> &Reference
Get a resolved or unresolved reference.
ReferenceIds can be found in IdentifierReference and similar nodes.
pub fn get_reference_mut(&mut self, reference_id: ReferenceId) -> &mut Reference
Sourcepub fn has_binding(&self, reference_id: ReferenceId) -> bool
pub fn has_binding(&self, reference_id: ReferenceId) -> bool
Returns true if the corresponding Reference is resolved to a symbol.
When false, this could either be a reference to a global value or an identifier that does
not exist.
Sourcepub fn get_resolved_reference_ids(
&self,
symbol_id: SymbolId,
) -> &Vec<'_, ReferenceId>
pub fn get_resolved_reference_ids( &self, symbol_id: SymbolId, ) -> &Vec<'_, ReferenceId>
Find Reference ids resolved to a symbol.
If you want direct access to a symbol’s References, use
SymbolTable::get_resolved_references.
Sourcepub fn get_resolved_references(
&self,
symbol_id: SymbolId,
) -> impl DoubleEndedIterator
pub fn get_resolved_references( &self, symbol_id: SymbolId, ) -> impl DoubleEndedIterator
Find References resolved to a symbol.
Sourcepub fn symbol_is_mutated(&self, symbol_id: SymbolId) -> bool
pub fn symbol_is_mutated(&self, symbol_id: SymbolId) -> bool
Get whether a symbol is mutated (i.e. assigned to).
If symbol is const, always returns false.
Otherwise, returns true if the symbol is assigned to somewhere in AST.
Sourcepub fn add_resolved_reference(
&mut self,
symbol_id: SymbolId,
reference_id: ReferenceId,
)
pub fn add_resolved_reference( &mut self, symbol_id: SymbolId, reference_id: ReferenceId, )
Add a reference to a symbol.
Sourcepub fn delete_resolved_reference(
&mut self,
symbol_id: SymbolId,
reference_id: ReferenceId,
)
pub fn delete_resolved_reference( &mut self, symbol_id: SymbolId, reference_id: ReferenceId, )
Delete a reference to a symbol.
Panics
Panics if provided reference_id is not a resolved reference for symbol_id.
pub fn reserve( &mut self, additional_symbols: usize, additional_references: usize, )