Trait BundlerFileSystem

pub trait BundlerFileSystem:
    FileSystem
    + Default
    + Clone
    + 'static { }
You don’t need impl this trait manually, it’s already implemented for all types that implement FileSystem + Default + Clone + 'static.

Notice on Clone constraint

Rolldown will access the passing file system from multiple places, which means rolldown will clone the file system multiple times. so it’s important to make sure these file system is unique. Rolldown could wrap the file system with Arc, but it will cause unnecessary overhead while using OS file system. So, it’s your responsibility to make sure that the file system is unique after cloning.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T: FileSystem + Default + Clone + 'static> BundlerFileSystem for T