Re-exports
pub use bundler_options::*;
Modules
- bundler_
options - This module is to help
rolldowncrate could export types related bundler options easily.rolldowncrate could usepub use rolldown_common::bundler_options::*;to export all types, so we don’t need write the same code inrolldowncrate again. - dynamic_
import_ usage - side_
effects
Structs
- AddEntry
Module Msg - Asset
- Assets is final output of the bundling process. Inputs -> Modules -> Chunks -> Assets
- Asset
Idx - Asset
View - AstScope
Idx - AstScopes
- Bundle
EndEvent Data - Cache
- Chunk
- Chunk
Idx - Chunk
Table - Cross
Chunk Import Item - CssAsset
Name Replacer - CssRenderer
- CssView
- Debug
Stmt Info ForTree Shaking - Ecma
Asset Meta - Ecma
AstIdx - Ecma
Module AstUsage - Ecma
Related - Ecma
View - Ecma
View Meta - Emitted
Asset - Emitted
Chunk - Emitted
Chunk Info - Entry
Point - External
Module - External
Module Idx - File
Emitter - Import
Meta Rolldown Asset Replacer - Import
Record Idx - Import
Record Meta - Importer
Record - Instantiated
Chunk InstantiatedChunks are derived fromChunks. DifferentInstantiatedChunks can be derived from the sameChunkby differentGenerators.- Local
Export - This is a representation for statements like
- Member
Expr Ref - For member expression, e.g.
foo_ns.bar_ns.c - Module
Id ModuleIdis the unique string identifier for each module.- Module
Idx - Module
Info - Module
Render Output - Module
Table - Modules
- Named
Import - This is a representation for statements like
- Namespace
Alias - Normal
Module - Normal
Module Task Result - Output
Asset - Output
Chunk - Outputs
Diagnostics - Package
Json - Preliminary
Filename - Represents a filename that might contains hash placeholder.
- Rendered
Module - Resolved
Export - Resolved
Id - Rollup
PreRendered Asset - Rollup
PreRendered Chunk - Rollup
Rendered Chunk - Runtime
Module Brief - Runtime
Module Task Result - Stmt
Info - Stmt
Info Idx - Stmt
Info Meta - Stmt
Infos - Symbol
Name RefToken - A token that represents a symbol name in a module.
- Symbol
Ref SymbolRefis used to represent a symbol in a module when there are multiple modules.- Symbol
RefDb - Symbol
RefDb ForModule - Symbol
RefFlags - Watcher
Change Data
Enums
- Bundle
Event - Chunk
Kind - Entry
Point Kind - Exports
Kind - Import
Kind - Instantiation
Kind - Interop
- Legacy
Module Idx - Module
- Module
DefFormat - Module Definition Format.
- Module
Loader Msg - Module
Render Args - Module
View - Output
- Specifier
- StrOr
Bytes - Symbol
OrMember Expr Ref - This
Expr Replace Kind - Watcher
Change Kind - Watcher
Event - Wrap
Kind
Constants
Statics
Traits
- Bundler
File System - You don’t need impl this trait manually, it’s already implemented for all types that implement
FileSystem + Default + Clone + 'static. - GetLocal
Db - Source
Mutation
Functions
- common_
debug_ symbol_ ref - passing a
SymbolRef, it will return it’s string repr, the format:${stable_id} -> ${symbol_name} - generate_
replace_ this_ expr_ map - get_
leading_ comment - Get the leading comment of a node when condition is satisfy
- is_
existing_ node_ builtin_ modules - Using
phfshould be faster, but it would increase the compile time, since this function is not frequently used, we usebinary_searchinstead.